﻿
using System.Windows;
using System.Windows.Controls;
using MindFusion.Scheduling.Wpf;
using System.Windows.Data;
using System.Globalization;
using System;
using System.Collections.Generic;

namespace CustomMonthCalendar
{
	public class CustomCellPresenter : CellPresenter
	{
		static CustomCellPresenter()
		{
			DefaultStyleKeyProperty.OverrideMetadata(typeof(CustomCellPresenter),
				new FrameworkPropertyMetadata(typeof(CustomCellPresenter)));
		}

		public CustomCellPresenter(MindFusion.Scheduling.Wpf.Calendar calendar, Dictionary<DateTime, CellInfo> cellInfo)
			: base(calendar)
		{
			this.cellInfo = cellInfo;
		}

		protected override void OnStartTimeChanged(DateTime oldTime, DateTime newTime)
		{
			base.OnStartTimeChanged(oldTime, newTime);

			CellInfo info;
			if (cellInfo.TryGetValue(newTime.Date, out info))
				CellInfo = info;
			else
				CellInfo = null;
		}


		public CellInfo CellInfo
		{
			get { return (CellInfo)GetValue(CellInfoProperty); }
			set { SetValue(CellInfoProperty, value); }
		}

		public static readonly DependencyProperty CellInfoProperty = DependencyProperty.Register(
			"CellInfo", typeof(CellInfo), typeof(CustomCellPresenter), new PropertyMetadata(null));


		private Dictionary<DateTime, CellInfo> cellInfo;
	}

	public class CellInfo
	{
		public int Total
		{
			get;
			set;
		}

		public int New
		{
			get;
			set;
		}

		public int Refill
		{
			get;
			set;
		}

		public int Change
		{
			get;
			set;
		}

		public int Extend
		{
			get;
			set;
		}
	}

	public class BooleanToVisibilityConverter : IValueConverter
	{
		public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
		{
			if (value is bool)
			{
				bool not = false;
				if (parameter != null)
				{
					if (!bool.TryParse(parameter.ToString(), out not))
						not = false;
				}

				return (not ^ (bool)value) ? Visibility.Visible : Visibility.Collapsed;
			}

			return value;
		}

		public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
		{
			throw new System.NotImplementedException();
		}
	}
}
