﻿
using System;
using System.Windows;
using System.Windows.Media;
using System.Windows.Input;
using System.Collections.Generic;
using System.Xml.Linq;
using System.IO;
using System.Globalization;


namespace CustomMonthCalendar
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		public MainWindow()
		{
			InitializeComponent();

			calendar2.Selection.Set(calendar.Date, calendar.EndDate);
			calendar2.Selection.Changed += (s, e) =>
				{
					if (calendar2.Selection.Ranges.Count > 0)
					{
						calendar.Date = calendar2.Selection.Ranges[0];
						calendar.EndDate = calendar2.Selection.Ranges[1];
					}
				};
			calendar2.MonthSettings.DaySettings.HeaderSize = 0;

			calendar.WeekRangeSettings.GroupWeekends = false;

			calendar.MonthSettings.HeaderStyles = MindFusion.Scheduling.Wpf.MonthHeaderStyles.None;
			calendar.MonthSettings.WeekHeaderStyle = MindFusion.Scheduling.Wpf.MonthWeekHeaderStyle.Left;

			var headerBrush = new LinearGradientBrush(
				new GradientStopCollection(
					new GradientStop[]
					{
						new GradientStop(Color.FromArgb(255, 228, 236, 246), 0),
						new GradientStop(Color.FromArgb(255, 214, 226, 241), 0.45),
						new GradientStop(Color.FromArgb(255, 194, 212, 235), 0.55),
						new GradientStop(Color.FromArgb(255, 208, 222, 239), 1),
					}), 90);

			calendar.WeekRangeSettings.TimePeriodHeaderHeight = 0;
			calendar.WeekRangeSettings.CellSettings.CalendarStyle.BorderBrush = new SolidColorBrush(Color.FromArgb(255, 74, 126, 187));
			calendar.WeekRangeSettings.CellSettings.CalendarStyle.BorderThickness = new Thickness(1);
			calendar.WeekRangeSettings.CellSettings.HeaderStyle.Background = headerBrush;
			calendar.WeekRangeSettings.CellSettings.HeaderStyle.BorderBrush = new SolidColorBrush(Color.FromArgb(255, 141, 174, 217));
			calendar.WeekRangeSettings.CellSettings.HeaderStyle.BorderThickness = new Thickness(0, 0, 0, 1);
			calendar.WeekRangeSettings.CellSettings.HeaderStyle.FontWeight = FontWeights.Bold;
			calendar.WeekRangeSettings.CellSettings.HeaderStyle.ContentMargin = new Thickness(2);
			calendar.WeekRangeSettings.CellSettings.HeaderStyle.HorizontalAlignment = System.Windows.HorizontalAlignment.Stretch;
			calendar.WeekRangeSettings.CellSettings.HeaderStyle.TextAlignment = TextAlignment.Left;
			calendar.WeekRangeSettings.CellSettings.FirstDayOfMonthFormat = "MMM d";

			calendar.MonthSettings.DaySettings.CalendarStyle.BorderBrush = new SolidColorBrush(Color.FromArgb(255, 74, 126, 187));
			calendar.MonthSettings.DaySettings.CalendarStyle.BorderThickness = new Thickness(1);
			calendar.MonthSettings.DaySettings.HeaderStyle.Background = headerBrush;
			calendar.MonthSettings.DaySettings.HeaderStyle.BorderBrush = new SolidColorBrush(Color.FromArgb(255, 141, 174, 217));
			calendar.MonthSettings.DaySettings.HeaderStyle.BorderThickness = new Thickness(0, 0, 0, 1);
			calendar.MonthSettings.DaySettings.HeaderStyle.FontWeight = FontWeights.Bold;
			calendar.MonthSettings.DaySettings.HeaderStyle.ContentMargin = new Thickness(2);
			calendar.MonthSettings.DaySettings.HeaderStyle.HorizontalAlignment = System.Windows.HorizontalAlignment.Stretch;
			calendar.MonthSettings.DaySettings.HeaderStyle.TextAlignment = TextAlignment.Left;
			calendar.MonthSettings.DaySettings.FirstDayOfMonthFormat = "MMM d";

			calendar.MonthSettings.PaddingDaysStyle.BorderBrush = new SolidColorBrush(Color.FromArgb(255, 74, 126, 187));
			calendar.MonthSettings.PaddingDaysStyle.BorderThickness = new Thickness(1);
			calendar.MonthSettings.PaddingDaysStyle.Background = new SolidColorBrush(Color.FromArgb(255, 165, 191, 225));
			calendar.MonthSettings.PaddingDaysHeaderStyle.BorderBrush = new SolidColorBrush(Color.FromArgb(255, 141, 174, 217));
			calendar.MonthSettings.PaddingDaysHeaderStyle.BorderThickness = new Thickness(0, 0, 0, 1);
			calendar.MonthSettings.PaddingDaysHeaderStyle.Background = headerBrush;
			calendar.MonthSettings.PaddingDaysHeaderStyle.FontWeight = FontWeights.Bold;
			calendar.MonthSettings.PaddingDaysHeaderStyle.ContentMargin = new Thickness(2);
			calendar.MonthSettings.PaddingDaysHeaderStyle.HorizontalAlignment = System.Windows.HorizontalAlignment.Stretch;
			calendar.MonthSettings.PaddingDaysHeaderStyle.TextAlignment = TextAlignment.Left;
			calendar.MonthSettings.PaddingDaysHeaderStyle.Foreground = Brushes.Black;

			calendar.MonthSettings.SubHeaderStyle.Background = new SolidColorBrush(Color.FromArgb(255, 227, 239, 255));

			calendar.CellPresenterCreating += calendar_CellPresenterCreating;

			r = new Random(DateTime.Now.Millisecond);

			// Load cell info
			string raw = @"<?xml version=""1.0"" encoding=""utf-8"" ?>
<info>
<data date=""24/04/2014"" New=""12"" Refill=""238"" Change=""230"" Extend=""240"" />
<data date=""25/04/2014"" New=""11"" Refill=""233"" Change=""240"" Extend=""140"" />
<data date=""26/04/2014"" New=""15"" Refill=""248"" Change=""220"" Extend=""160"" />
<data date=""27/04/2014"" New=""32"" Refill=""241"" Change=""210"" Extend=""180"" />
<data date=""28/04/2014"" New=""32"" Refill=""231"" Change=""130"" Extend=""320"" />
<data date=""29/04/2014"" New=""34"" Refill=""221"" Change=""430"" Extend=""325"" />
<data date=""30/04/2014"" New=""45"" Refill=""123"" Change=""230"" Extend=""114"" />
<data date=""31/04/2014"" New=""54"" Refill=""234"" Change=""130"" Extend=""118"" />
<data date=""01/05/2014"" New=""65"" Refill=""234"" Change=""235"" Extend=""112"" />
<data date=""02/05/2014"" New=""56"" Refill=""342"" Change=""236"" Extend=""120"" />
<data date=""03/05/2014"" New=""32"" Refill=""345"" Change=""248"" Extend=""310"" />
<data date=""04/05/2014"" New=""11"" Refill=""365"" Change=""258"" Extend=""311"" />
<data date=""05/05/2014"" New=""10"" Refill=""456"" Change=""230"" Extend=""121"" />
</info>";
			StringReader reader = new StringReader(raw);
			XDocument doc = XDocument.Load(reader);
			var elements = doc.Element("info").Elements("data");
			cellInfo = new Dictionary<DateTime, CellInfo>();
			foreach (var e in elements)
			{
				DateTime date;
				if (!DateTime.TryParseExact(e.Attribute("date").Value, "dd/MM/yyyy", CultureInfo.InvariantCulture, System.Globalization.DateTimeStyles.None, out date))
					continue;

				int n, refill, change, extend;
				if (!int.TryParse(e.Attribute("New").Value, out n))
					continue;
				if (!int.TryParse(e.Attribute("Refill").Value, out refill))
					continue;
				if (!int.TryParse(e.Attribute("Change").Value, out change))
					continue;
				if (!int.TryParse(e.Attribute("Extend").Value, out extend))
					continue;

				cellInfo[date] = new CellInfo() { New = n, Refill = refill, Change = change, Extend = extend, Total = n + refill + change + extend };
			}
		}

		private Dictionary<DateTime, CellInfo> cellInfo;

		private void CanBrowseBack(object sender, CanExecuteRoutedEventArgs e)
		{
			e.CanExecute = true;
		}

		private void OnBrowseBack(object sender, ExecutedRoutedEventArgs e)
		{
			calendar.Date = calendar.Date.AddMonths(-1);
		}

		private void CanBrowseForward(object sender, CanExecuteRoutedEventArgs e)
		{
			e.CanExecute = true;
		}

		private void OnBrowseForward(object sender, ExecutedRoutedEventArgs e)
		{
			calendar.Date = calendar.Date.AddMonths(1);
		}

		void calendar_CellPresenterCreating(object sender, MindFusion.Scheduling.CellPresenterCreatingEventArgs e)
		{
			var presenter = new CustomCellPresenter(calendar, cellInfo);
			//var info = new CellInfo()
			//{
			//    New = r.Next(128),
			//    Refill = r.Next(255),
			//    Change = r.Next(64),
			//    Extend = r.Next(16),
			//};
			//info.Total = info.New + info.Refill + info.Change + info.Extend;
			e.CellPresenter = presenter;
		}


		private Random r;
	}
}
